@@ -174,7 +174,9 @@ class TestManager:
                 os.environ.pop("WAYLAND_DISPLAY", None)
                 kore = self.backend.create()
                 os.environ.update(self.backend.env)
-                init_log(self.log_level, log_path=None, log_color=False)
+                logger = init_log(self.log_level, log_path=None, log_color=False)
+                if hasattr(self, "log_queue"):
+                    logger.addHandler(logging.handlers.QueueHandler(self.log_queue))
                 Qtile(
                     kore,
                     config_class(),
