@@ -66,6 +66,39 @@ def test_no_size_hint(manager):
     assert manager.c.window.info()["height"] == 200
 
 
+@bare_config
+def test_togroup_toggle(manager):
+    manager.test_window("one")
+    assert manager.c.group.info()["name"] == "a"  # Start on "a"
+    assert manager.c.groups()["a"]["focus"] == "one"
+    assert manager.c.groups()["b"]["focus"] is None
+    manager.c.window.togroup("b", switch_group=True)
+    assert manager.c.group.info()["name"] == "b"  # Move the window and switch to "b"
+    assert manager.c.groups()["a"]["focus"] is None
+    assert manager.c.groups()["b"]["focus"] == "one"
+    manager.c.window.togroup("b", switch_group=True)
+    assert manager.c.group.info()["name"] == "b"  # Does not toggle by default
+    assert manager.c.groups()["a"]["focus"] is None
+    assert manager.c.groups()["b"]["focus"] == "one"
+    manager.c.window.togroup("b", switch_group=True, toggle=True)
+    assert (
+        manager.c.group.info()["name"] == "a"
+    )  # Explicitly toggling moves the window and switches to "a"
+    assert manager.c.groups()["a"]["focus"] == "one"
+    assert manager.c.groups()["b"]["focus"] is None
+    manager.c.window.togroup("b", switch_group=True, toggle=True)
+    manager.c.window.togroup("b", switch_group=True, toggle=True)
+    assert manager.c.group.info()["name"] == "a"  # Toggling twice roundtrips between the two
+    assert manager.c.groups()["a"]["focus"] == "one"
+    assert manager.c.groups()["b"]["focus"] is None
+    manager.c.window.togroup("b", toggle=True)
+    assert (
+        manager.c.group.info()["name"] == "a"
+    )  # Toggling without switching only moves the window
+    assert manager.c.groups()["a"]["focus"] is None
+    assert manager.c.groups()["b"]["focus"] == "one"
+
+
 class BringFrontClickConfig(ManagerConfig):
     bring_front_click = True
 
@@ -127,3 +160,24 @@ def test_bring_front_click(manager, bring_front_click):
         assert wins.index(wids[2]) < wins.index(wids[1]) < wins.index(wids[0])
     else:
         assert wins.index(wids[0]) < wins.index(wids[1]) < wins.index(wids[2])
+
+
+@bare_config
+def test_center_window(manager):
+    """Check that floating windows are centered correctly."""
+    manager.test_window("one")
+
+    manager.c.window.set_position_floating(50, 50)
+    manager.c.window.set_size_floating(200, 100)
+    info = manager.c.window.info()
+    assert info["x"] == 50
+    assert info["y"] == 50
+    assert info["width"] == 200
+    assert info["height"] == 100
+
+    manager.c.window.center()
+    info = manager.c.window.info()
+    assert info["x"] == (800 - 200) / 2  # (screen width - window width) / 2
+    assert info["y"] == (600 - 100) / 2  # (screen height - window height) / 2
+    assert info["width"] == 200
+    assert info["height"] == 100
